# JournalRunTransactionType

Transaction type. Invoice Adjustment is deprecated on Production. Zuora recommends that you use the Invoice Item Adjustment instead. If you enable the Invoice Settlement feature, Debit Memo Item, Credit Memo Item, and Credit Memo Application Item are available, Payment and Refund will be replaced by Payment Application and Refund Application. If you enable both the Invoice Settlement feature and the Invoice Item Settlement feature, Payment and Refund will be replaced by Payment Application Item and Refund Application Item.

## Enum

* `INVOICE_ITEM` (value: `'Invoice Item'`)

* `TAXATION_ITEM` (value: `'Taxation Item'`)

* `INVOICE_ITEM_ADJUSTMENT_LEFT_PARENTHESIS_INVOICE_RIGHT_PARENTHESIS` (value: `'Invoice Item Adjustment (Invoice)'`)

* `INVOICE_ITEM_ADJUSTMENT_LEFT_PARENTHESIS_TAX_RIGHT_PARENTHESIS` (value: `'Invoice Item Adjustment (Tax)'`)

* `INVOICE_ADJUSTMENT` (value: `'Invoice Adjustment'`)

* `ELECTRONIC_PAYMENT` (value: `'Electronic Payment'`)

* `EXTERNAL_PAYMENT` (value: `'External Payment'`)

* `ELECTRONIC_REFUND` (value: `'Electronic Refund'`)

* `EXTERNAL_REFUND` (value: `'External Refund'`)

* `ELECTRONIC_CREDIT_BALANCE_PAYMENT` (value: `'Electronic Credit Balance Payment'`)

* `EXTERNAL_CREDIT_BALANCE_PAYMENT` (value: `'External Credit Balance Payment'`)

* `ELECTRONIC_CREDIT_BALANCE_REFUND` (value: `'Electronic Credit Balance Refund'`)

* `EXTERNAL_CREDIT_BALANCE_REFUND` (value: `'External Credit Balance Refund'`)

* `CREDIT_BALANCE_ADJUSTMENT_LEFT_PARENTHESIS_APPLIED_FROM_CREDIT_BALANCE_RIGHT_PARENTHESIS` (value: `'Credit Balance Adjustment (Applied from Credit Balance)'`)

* `CREDIT_BALANCE_ADJUSTMENT_LEFT_PARENTHESIS_TRANSFERRED_TO_CREDIT_BALANCE_RIGHT_PARENTHESIS` (value: `'Credit Balance Adjustment (Transferred to Credit Balance)'`)

* `REVENUE_EVENT_ITEM` (value: `'Revenue Event Item'`)

* `DEBIT_MEMO_ITEM_LEFT_PARENTHESIS_CHARGE_RIGHT_PARENTHESIS` (value: `'Debit Memo Item (Charge)'`)

* `DEBIT_MEMO_ITEM_LEFT_PARENTHESIS_TAX_RIGHT_PARENTHESIS` (value: `'Debit Memo Item (Tax)'`)

* `CREDIT_MEMO_ITEM_LEFT_PARENTHESIS_CHARGE_RIGHT_PARENTHESIS` (value: `'Credit Memo Item (Charge)'`)

* `CREDIT_MEMO_ITEM_LEFT_PARENTHESIS_TAX_RIGHT_PARENTHESIS` (value: `'Credit Memo Item (Tax)'`)

* `CREDIT_MEMO_APPLICATION_ITEM` (value: `'Credit Memo Application Item'`)

* `ELECTRONIC_PAYMENT_APPLICATION` (value: `'Electronic Payment Application'`)

* `EXTERNAL_PAYMENT_APPLICATION` (value: `'External Payment Application'`)

* `ELECTRONIC_REFUND_APPLICATION` (value: `'Electronic Refund Application'`)

* `EXTERNAL_REFUND_APPLICATION` (value: `'External Refund Application'`)

* `ELECTRONIC_PAYMENT_APPLICATION_ITEM` (value: `'Electronic Payment Application Item'`)

* `EXTERNAL_PAYMENT_APPLICATION_ITEM` (value: `'External Payment Application Item'`)

* `ELECTRONIC_REFUND_APPLICATION_ITEM` (value: `'Electronic Refund Application Item'`)

* `EXTERNAL_REFUND_APPLICATION_ITEM` (value: `'External Refund Application Item'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


